# logicdrop-sparks-openapi
Generated documentation for the Logicdrop Sparks API and OpenAPI clients.

Logicdrop Sparks lets users build rules, analyze data, and automate
documents.

Use it to make decisions faster, generate documents better, and learn
from your data.

### Documentation
- [User Documentation](https://docs.logicdrop.com)

### Modules
- [Sparks Compute](https://docs.logicdrop.com/rules/introduction)
- [Sparks Decision Tables](https://docs.logicdrop.com/rules/authoring-decision-tables)
- [Sparks Documents](https://docs.logicdrop.com/documents/introduction)

### Clients
- [OpenAPI Clients](https://docs.logicdrop.com/development/sample-clients)

### Security
- [Authorizing API Requests](https://docs.logicdrop.com/development/authorization)


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v_VERSION_._BUILD_
- Package version: 4.3.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://support.logicdrop.com](https://support.logicdrop.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import logicdrop.sparks.openapi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import logicdrop.sparks.openapi
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import logicdrop.sparks.openapi
from logicdrop.sparks.openapi.rest import ApiException
from pprint import pprint

configuration = logicdrop.sparks.openapi.Configuration()
# Configure API key authorization: api
configuration.api_key['X-Logicdrop-ApiKey'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-Logicdrop-ApiKey'] = 'Bearer'
configuration = logicdrop.sparks.openapi.Configuration()
# Configure Bearer authorization (JWT): jwt
configuration.access_token = 'YOUR_BEARER_TOKEN'
configuration = logicdrop.sparks.openapi.Configuration()
# Configure OAuth2 access token for authorization: oauth2
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# Defining host is optional and default to https://api.staging.com
configuration.host = "https://api.staging.com"
# Enter a context with an instance of the API client
with logicdrop.sparks.openapi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = logicdrop.sparks.openapi.AdminServicesApi(api_client)
    client = 'client_example' # str | Client name

    try:
        # Delete client
        api_response = api_instance.admin_delete_client(client)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AdminServicesApi->admin_delete_client: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://api.staging.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminServicesApi* | [**admin_delete_client**](docs/AdminServicesApi.md#admin_delete_client) | **DELETE** /admin/clients/{client} | Delete client
*AdminServicesApi* | [**admin_delete_user**](docs/AdminServicesApi.md#admin_delete_user) | **DELETE** /admin/clients/{client}/users | Delete user
*AdminServicesApi* | [**admin_get_client**](docs/AdminServicesApi.md#admin_get_client) | **GET** /admin/clients/{client} | Get client
*AdminServicesApi* | [**admin_get_permissions**](docs/AdminServicesApi.md#admin_get_permissions) | **GET** /admin/users | Get user permissions
*AdminServicesApi* | [**admin_invite_user**](docs/AdminServicesApi.md#admin_invite_user) | **POST** /admin/clients/{client}/users/invite | Invite a user
*AdminServicesApi* | [**admin_list_clients**](docs/AdminServicesApi.md#admin_list_clients) | **GET** /admin/clients | Get clients
*AdminServicesApi* | [**admin_list_users**](docs/AdminServicesApi.md#admin_list_users) | **GET** /admin/clients/{client}/users | Admin List users
*AdminServicesApi* | [**admin_update_client**](docs/AdminServicesApi.md#admin_update_client) | **PATCH** /admin/clients/{client} | Update client
*AdminServicesApi* | [**admin_update_status**](docs/AdminServicesApi.md#admin_update_status) | **PATCH** /admin/clients/{client}/status | Update client status
*AdminServicesApi* | [**admin_update_subscription**](docs/AdminServicesApi.md#admin_update_subscription) | **PATCH** /admin/clients/{client}/subscription | Update client subscription
*AdminServicesApi* | [**admin_update_user**](docs/AdminServicesApi.md#admin_update_user) | **PATCH** /admin/clients/{client}/users | Update user
*CacheServicesApi* | [**evict_entry**](docs/CacheServicesApi.md#evict_entry) | **DELETE** /caches/{client}/{cache}/{key} | Evict cache entry
*CacheServicesApi* | [**flush_cache**](docs/CacheServicesApi.md#flush_cache) | **DELETE** /caches/{client}/{cache} | Flush cache
*CacheServicesApi* | [**get_entries**](docs/CacheServicesApi.md#get_entries) | **GET** /caches/{client}/{cache} | List cache entries
*CacheServicesApi* | [**get_entry**](docs/CacheServicesApi.md#get_entry) | **GET** /caches/{client}/{cache}/{key} | Get cache entry
*CacheServicesApi* | [**list_caches**](docs/CacheServicesApi.md#list_caches) | **GET** /caches/{client} | List caches
*CacheServicesApi* | [**put_entry**](docs/CacheServicesApi.md#put_entry) | **PUT** /caches/{client}/{cache} | Put cache entry
*ClientServicesApi* | [**create_application**](docs/ClientServicesApi.md#create_application) | **PUT** /clients/{client}/applications | Create application
*ClientServicesApi* | [**delete_application**](docs/ClientServicesApi.md#delete_application) | **DELETE** /clients/{client}/applications/{id} | Delete application
*ClientServicesApi* | [**delete_client**](docs/ClientServicesApi.md#delete_client) | **DELETE** /clients/{client} | Delete client
*ClientServicesApi* | [**delete_user**](docs/ClientServicesApi.md#delete_user) | **DELETE** /clients/{client}/users | Delete user
*ClientServicesApi* | [**get_client**](docs/ClientServicesApi.md#get_client) | **GET** /clients/{client} | Get client
*ClientServicesApi* | [**get_secret**](docs/ClientServicesApi.md#get_secret) | **GET** /clients/{client}/applications/{id} | Get secret
*ClientServicesApi* | [**invite_user**](docs/ClientServicesApi.md#invite_user) | **POST** /clients/{client}/users/invite | Invite user
*ClientServicesApi* | [**list_applications**](docs/ClientServicesApi.md#list_applications) | **GET** /clients/{client}/applications | Get applications
*ClientServicesApi* | [**list_users**](docs/ClientServicesApi.md#list_users) | **GET** /clients/{client}/users | List users
*ClientServicesApi* | [**rotate_secret**](docs/ClientServicesApi.md#rotate_secret) | **POST** /clients/{client}/applications/{id}/rotate | Rotate secret
*ClientServicesApi* | [**update_client**](docs/ClientServicesApi.md#update_client) | **PATCH** /clients/{client} | Update client
*ClientServicesApi* | [**update_user**](docs/ClientServicesApi.md#update_user) | **PATCH** /clients/{client}/users | Update user
*ComputeServicesApi* | [**debug_rules**](docs/ComputeServicesApi.md#debug_rules) | **POST** /compute/{client}/debug | Debug rules
*ComputeServicesApi* | [**delete_rule**](docs/ComputeServicesApi.md#delete_rule) | **DELETE** /compute/{client}/{project}/{artifact}/rules/{id} | Delete rule
*ComputeServicesApi* | [**delete_rules**](docs/ComputeServicesApi.md#delete_rules) | **DELETE** /compute/{client}/{project}/{artifact}/rules | Delete rules
*ComputeServicesApi* | [**delete_ruleset**](docs/ComputeServicesApi.md#delete_ruleset) | **DELETE** /compute/{client}/{project}/{artifact} | Delete ruleset
*ComputeServicesApi* | [**delete_rulesets**](docs/ComputeServicesApi.md#delete_rulesets) | **DELETE** /compute/{client}/{project} | Delete rulesets
*ComputeServicesApi* | [**execute_rules**](docs/ComputeServicesApi.md#execute_rules) | **POST** /compute/{client}/execute | Execute ruleset
*ComputeServicesApi* | [**generate_rules**](docs/ComputeServicesApi.md#generate_rules) | **POST** /compute/{client}/debug/source | Generate rules
*ComputeServicesApi* | [**generate_ruleset**](docs/ComputeServicesApi.md#generate_ruleset) | **GET** /compute/{client}/{project}/{artifact}/generate | Generate ruleset
*ComputeServicesApi* | [**get_rule**](docs/ComputeServicesApi.md#get_rule) | **GET** /compute/{client}/{project}/{artifact}/rules/{id} | Get rule
*ComputeServicesApi* | [**get_ruleset**](docs/ComputeServicesApi.md#get_ruleset) | **GET** /compute/{client}/{project}/{artifact} | Get ruleset
*ComputeServicesApi* | [**get_ruleset_content**](docs/ComputeServicesApi.md#get_ruleset_content) | **GET** /compute/{client}/{project}/{artifact}/content | Get content
*ComputeServicesApi* | [**get_ruleset_example**](docs/ComputeServicesApi.md#get_ruleset_example) | **GET** /compute/{client}/{project}/{artifact}/example | Get example request
*ComputeServicesApi* | [**list_containers**](docs/ComputeServicesApi.md#list_containers) | **GET** /compute/{client}/containers | List containers
*ComputeServicesApi* | [**list_rules**](docs/ComputeServicesApi.md#list_rules) | **GET** /compute/{client}/{project}/{artifact}/rules | List rules
*ComputeServicesApi* | [**list_rules_by_key**](docs/ComputeServicesApi.md#list_rules_by_key) | **GET** /compute/{client}/{project}/{artifact}/rules/{key}/{value} | List rules by key
*ComputeServicesApi* | [**list_rulesets**](docs/ComputeServicesApi.md#list_rulesets) | **GET** /compute/{client}/{project} | List rulesets
*ComputeServicesApi* | [**manage_container**](docs/ComputeServicesApi.md#manage_container) | **POST** /compute/{client}/containers | Manage containers
*ComputeServicesApi* | [**save_rule**](docs/ComputeServicesApi.md#save_rule) | **PUT** /compute/{client}/{project}/{artifact}/rules | Save rule
*ComputeServicesApi* | [**save_ruleset**](docs/ComputeServicesApi.md#save_ruleset) | **PUT** /compute/{client}/{project} | Save ruleset
*ComputeServicesApi* | [**update_ruleset**](docs/ComputeServicesApi.md#update_ruleset) | **PATCH** /compute/{client}/{project} | Update ruleset
*ComputeServicesApi* | [**update_ruleset_content_file**](docs/ComputeServicesApi.md#update_ruleset_content_file) | **POST** /compute/{client}/{project}/{artifact}/content | Update content using file
*ComputeServicesApi* | [**update_ruleset_content_text**](docs/ComputeServicesApi.md#update_ruleset_content_text) | **PATCH** /compute/{client}/{project}/{artifact}/content | Update content using string
*ComputeServicesApi* | [**update_ruleset_example**](docs/ComputeServicesApi.md#update_ruleset_example) | **PATCH** /compute/{client}/{project}/{artifact}/example | Update example request
*ComputeServicesApi* | [**update_rulesets**](docs/ComputeServicesApi.md#update_rulesets) | **POST** /compute/{client}/{project} | Update rulesets
*ComputeServicesApi* | [**upload_workbook**](docs/ComputeServicesApi.md#upload_workbook) | **POST** /compute/{client}/{project}/{artifact}/upload | Upload workbook
*ContentServicesApi* | [**delete_content**](docs/ContentServicesApi.md#delete_content) | **DELETE** /content/{client}/{folders}/{filename}.{extension} | Delete content
*ContentServicesApi* | [**delete_private_content**](docs/ContentServicesApi.md#delete_private_content) | **DELETE** /content/{client}/private/{folders}/{filename}.{extension} | Delete private content
*ContentServicesApi* | [**get_content**](docs/ContentServicesApi.md#get_content) | **GET** /content/{client}/{folders}/{filename}.{extension} | Get content
*ContentServicesApi* | [**get_private_content**](docs/ContentServicesApi.md#get_private_content) | **GET** /content/{client}/private/{folders}/{filename}.{extension} | Get private content
*ContentServicesApi* | [**get_signed_token**](docs/ContentServicesApi.md#get_signed_token) | **GET** /content/{client}/signed/{folders}/{filename}.{extension} | Get signed token
*ContentServicesApi* | [**list_content**](docs/ContentServicesApi.md#list_content) | **GET** /content/{client}/{folders} | List contents
*ContentServicesApi* | [**list_private_content**](docs/ContentServicesApi.md#list_private_content) | **GET** /content/{client}/private/{folders} | List private contents
*ContentServicesApi* | [**upload_content**](docs/ContentServicesApi.md#upload_content) | **POST** /content/{client}/{folders}/upload | Upload content
*ContentServicesApi* | [**upload_private_content**](docs/ContentServicesApi.md#upload_private_content) | **POST** /content/{client}/private/{folders}/upload | Upload private content
*DataServicesApi* | [**delete_dataset**](docs/DataServicesApi.md#delete_dataset) | **DELETE** /data/{client}/{project}/{artifact} | Delete dataset
*DataServicesApi* | [**delete_datasets**](docs/DataServicesApi.md#delete_datasets) | **DELETE** /data/{client}/{project} | Delete datasets
*DataServicesApi* | [**delete_record**](docs/DataServicesApi.md#delete_record) | **DELETE** /data/{client}/{project}/{artifact}/rows/{id} | Delete record
*DataServicesApi* | [**delete_records**](docs/DataServicesApi.md#delete_records) | **DELETE** /data/{client}/{project}/{artifact}/rows | Delete records
*DataServicesApi* | [**get_dataset**](docs/DataServicesApi.md#get_dataset) | **GET** /data/{client}/{project}/{artifact} | Get dataset
*DataServicesApi* | [**get_dataset_content**](docs/DataServicesApi.md#get_dataset_content) | **GET** /data/{client}/{project}/{artifact}/content | Get content
*DataServicesApi* | [**get_record**](docs/DataServicesApi.md#get_record) | **GET** /data/{client}/{project}/{artifact}/rows/{id} | Get record
*DataServicesApi* | [**list_datasets**](docs/DataServicesApi.md#list_datasets) | **GET** /data/{client}/{project} | List datasets
*DataServicesApi* | [**list_records**](docs/DataServicesApi.md#list_records) | **GET** /data/{client}/{project}/{artifact}/rows | List records
*DataServicesApi* | [**list_records_by_key**](docs/DataServicesApi.md#list_records_by_key) | **GET** /data/{client}/{project}/{artifact}/rows/{key}/{value} | List records by key
*DataServicesApi* | [**list_sources**](docs/DataServicesApi.md#list_sources) | **GET** /data/{client}/sources | List external sources
*DataServicesApi* | [**save_dataset**](docs/DataServicesApi.md#save_dataset) | **PUT** /data/{client}/{project} | Save dataset
*DataServicesApi* | [**save_dataset_content**](docs/DataServicesApi.md#save_dataset_content) | **PUT** /data/{client}/{project}/{artifact}/content | Save content
*DataServicesApi* | [**save_record**](docs/DataServicesApi.md#save_record) | **PUT** /data/{client}/{project}/{artifact}/rows | Save record
*DataServicesApi* | [**update_dataset**](docs/DataServicesApi.md#update_dataset) | **PATCH** /data/{client}/{project} | Update dataset
*DataServicesApi* | [**update_dataset_content**](docs/DataServicesApi.md#update_dataset_content) | **PATCH** /data/{client}/{project}/{artifact}/content | Update content
*DataServicesApi* | [**update_dataset_content_at**](docs/DataServicesApi.md#update_dataset_content_at) | **PATCH** /data/{client}/{project}/{artifact}/content/{index} | Update content item
*DataServicesApi* | [**update_datasets**](docs/DataServicesApi.md#update_datasets) | **POST** /data/{client}/{project} | Update datasets
*DataServicesApi* | [**update_records**](docs/DataServicesApi.md#update_records) | **PATCH** /data/{client}/{project}/{artifact}/rows | Update records
*DataServicesApi* | [**upload_dataset**](docs/DataServicesApi.md#upload_dataset) | **POST** /data/{client}/{project}/{artifact}/import | Import datasets
*EmailServicesApi* | [**send_email**](docs/EmailServicesApi.md#send_email) | **POST** /email/{client} | Send email
*EmailServicesApi* | [**send_with_attachment**](docs/EmailServicesApi.md#send_with_attachment) | **POST** /email/{client}/send | Send email with attachments
*KioskServicesApi* | [**check_availability**](docs/KioskServicesApi.md#check_availability) | **GET** /checkname | Check name availability
*KioskServicesApi* | [**get_user_info**](docs/KioskServicesApi.md#get_user_info) | **GET** /userinfo | Get user info
*KioskServicesApi* | [**get_user_profile**](docs/KioskServicesApi.md#get_user_profile) | **GET** /userinfo/profile | Get user profile
*KioskServicesApi* | [**redeem**](docs/KioskServicesApi.md#redeem) | **GET** /redeem | Redeem invite token
*KioskServicesApi* | [**register_client**](docs/KioskServicesApi.md#register_client) | **POST** /signup | Register client
*KioskServicesApi* | [**register_user**](docs/KioskServicesApi.md#register_user) | **POST** /register | Register user
*OfficeServicesApi* | [**upload_documents**](docs/OfficeServicesApi.md#upload_documents) | **POST** /office/{client}/{project}/documents/upload | Upload documents
*PackageServicesApi* | [**delete_package**](docs/PackageServicesApi.md#delete_package) | **DELETE** /packages/{client}/{package} | Delete package
*PackageServicesApi* | [**get_package**](docs/PackageServicesApi.md#get_package) | **GET** /packages/{client}/{package} | Get package
*PackageServicesApi* | [**list_packages**](docs/PackageServicesApi.md#list_packages) | **GET** /packages/{client} | List packages
*PackageServicesApi* | [**scaffold_project**](docs/PackageServicesApi.md#scaffold_project) | **POST** /packages/{client}/scaffold | Scaffold project
*PackageServicesApi* | [**upload_package**](docs/PackageServicesApi.md#upload_package) | **POST** /packages/{client} | Upload packages
*PlatformServicesApi* | [**list_managed_services**](docs/PlatformServicesApi.md#list_managed_services) | **GET** /manage/{service} | List managed services
*PlatformServicesApi* | [**manage_service**](docs/PlatformServicesApi.md#manage_service) | **POST** /manage/{service} | Manage service
*PlatformServicesApi* | [**platform_info**](docs/PlatformServicesApi.md#platform_info) | **GET** /info | Platform details
*ProjectServicesApi* | [**delete_project**](docs/ProjectServicesApi.md#delete_project) | **DELETE** /projects/{client}/{project} | Delete project
*ProjectServicesApi* | [**delete_projects**](docs/ProjectServicesApi.md#delete_projects) | **DELETE** /projects/{client} | Delete projects
*ProjectServicesApi* | [**get_project**](docs/ProjectServicesApi.md#get_project) | **GET** /projects/{client}/{project} | Get project
*ProjectServicesApi* | [**list_projects**](docs/ProjectServicesApi.md#list_projects) | **GET** /projects/{client} | List projects
*ProjectServicesApi* | [**list_references**](docs/ProjectServicesApi.md#list_references) | **GET** /projects/{client}/{project}/references | List references
*ProjectServicesApi* | [**save_project**](docs/ProjectServicesApi.md#save_project) | **PUT** /projects/{client} | Save project
*ProjectServicesApi* | [**update_project**](docs/ProjectServicesApi.md#update_project) | **PATCH** /projects/{client} | Update project
*ProjectServicesApi* | [**update_projects**](docs/ProjectServicesApi.md#update_projects) | **POST** /projects/{client} | Update projects
*QueryServicesApi* | [**delete_queries**](docs/QueryServicesApi.md#delete_queries) | **DELETE** /query/{client}/{project} | Delete queries
*QueryServicesApi* | [**delete_query**](docs/QueryServicesApi.md#delete_query) | **DELETE** /query/{client}/{project}/{artifact} | Delete query
*QueryServicesApi* | [**execute_query**](docs/QueryServicesApi.md#execute_query) | **POST** /query/{client}/execute | Execute live query
*QueryServicesApi* | [**get_query**](docs/QueryServicesApi.md#get_query) | **GET** /query/{client}/{project}/{artifact} | Get query
*QueryServicesApi* | [**list_queries**](docs/QueryServicesApi.md#list_queries) | **GET** /query/{client}/{project} | List queries
*QueryServicesApi* | [**run_query**](docs/QueryServicesApi.md#run_query) | **GET** /query/{client}/{project}/{artifact}/run | Execute saved query
*QueryServicesApi* | [**save_query**](docs/QueryServicesApi.md#save_query) | **PUT** /query/{client}/{project} | Save query
*QueryServicesApi* | [**update_queries**](docs/QueryServicesApi.md#update_queries) | **POST** /query/{client}/{project} | Update queries
*QueryServicesApi* | [**update_query**](docs/QueryServicesApi.md#update_query) | **PATCH** /query/{client}/{project} | Update query
*SchemaServicesApi* | [**delete_schema**](docs/SchemaServicesApi.md#delete_schema) | **DELETE** /schemas/{client}/{project}/{artifact} | Delete schema
*SchemaServicesApi* | [**delete_schemas**](docs/SchemaServicesApi.md#delete_schemas) | **DELETE** /schemas/{client}/{project} | Delete schemas
*SchemaServicesApi* | [**get_schema**](docs/SchemaServicesApi.md#get_schema) | **GET** /schemas/{client}/{project}/{artifact} | Get schema
*SchemaServicesApi* | [**list_schemas**](docs/SchemaServicesApi.md#list_schemas) | **GET** /schemas/{client}/{project} | List schemas
*SchemaServicesApi* | [**save_schema**](docs/SchemaServicesApi.md#save_schema) | **PUT** /schemas/{client}/{project} | Save schema
*SchemaServicesApi* | [**update_schema**](docs/SchemaServicesApi.md#update_schema) | **PATCH** /schemas/{client}/{project} | Update schema
*SchemaServicesApi* | [**update_schemas**](docs/SchemaServicesApi.md#update_schemas) | **POST** /schemas/{client}/{project} | Update schemas
*SecurityServicesApi* | [**get_public_key**](docs/SecurityServicesApi.md#get_public_key) | **GET** /.well-known/jwks.json | Get public key
*TemplateServicesApi* | [**delete_template**](docs/TemplateServicesApi.md#delete_template) | **DELETE** /templates/{client}/{project}/{artifact} | Delete template
*TemplateServicesApi* | [**delete_templates**](docs/TemplateServicesApi.md#delete_templates) | **DELETE** /templates/{client}/{project} | Delete templates
*TemplateServicesApi* | [**get_template**](docs/TemplateServicesApi.md#get_template) | **GET** /templates/{client}/{project}/{artifact} | Get template
*TemplateServicesApi* | [**list_templates**](docs/TemplateServicesApi.md#list_templates) | **GET** /templates/{client}/{project} | List templates
*TemplateServicesApi* | [**save_template**](docs/TemplateServicesApi.md#save_template) | **PUT** /templates/{client}/{project} | Save template
*TemplateServicesApi* | [**update_template**](docs/TemplateServicesApi.md#update_template) | **PATCH** /templates/{client}/{project} | Update template
*TemplateServicesApi* | [**update_templates**](docs/TemplateServicesApi.md#update_templates) | **POST** /templates/{client}/{project} | Update templates


## Documentation For Models

 - [ArtifactReference](docs/ArtifactReference.md)
 - [ArtifactResponse](docs/ArtifactResponse.md)
 - [Assertion](docs/Assertion.md)
 - [BetweenQueryField](docs/BetweenQueryField.md)
 - [BetweenQueryFieldAllOf](docs/BetweenQueryFieldAllOf.md)
 - [Bundle](docs/Bundle.md)
 - [CacheRequest](docs/CacheRequest.md)
 - [CacheRequestValue](docs/CacheRequestValue.md)
 - [CacheResult](docs/CacheResult.md)
 - [Client](docs/Client.md)
 - [ClientRegistration](docs/ClientRegistration.md)
 - [ClientSettings](docs/ClientSettings.md)
 - [ComputeOptions](docs/ComputeOptions.md)
 - [ComputeRule](docs/ComputeRule.md)
 - [ComputeRuleset](docs/ComputeRuleset.md)
 - [ConditionQueryField](docs/ConditionQueryField.md)
 - [ConditionQueryFieldAllOf](docs/ConditionQueryFieldAllOf.md)
 - [ContainerResponse](docs/ContainerResponse.md)
 - [CriteriaQueryField](docs/CriteriaQueryField.md)
 - [CriteriaQueryFieldObject](docs/CriteriaQueryFieldObject.md)
 - [DataResponse](docs/DataResponse.md)
 - [DataResult](docs/DataResult.md)
 - [Dataset](docs/Dataset.md)
 - [DeleteArtifactRequest](docs/DeleteArtifactRequest.md)
 - [DeleteDataRequest](docs/DeleteDataRequest.md)
 - [DesignRulesRequest](docs/DesignRulesRequest.md)
 - [DesignerEvent](docs/DesignerEvent.md)
 - [DesignerOptions](docs/DesignerOptions.md)
 - [DesignerResult](docs/DesignerResult.md)
 - [EmailMessage](docs/EmailMessage.md)
 - [EmailResult](docs/EmailResult.md)
 - [EmailWithAttachment](docs/EmailWithAttachment.md)
 - [ExternalSource](docs/ExternalSource.md)
 - [Field](docs/Field.md)
 - [FileResult](docs/FileResult.md)
 - [GenerateRulesRequest](docs/GenerateRulesRequest.md)
 - [IdentityApplication](docs/IdentityApplication.md)
 - [IdentityMessage](docs/IdentityMessage.md)
 - [IdentityUser](docs/IdentityUser.md)
 - [MultipartRequest](docs/MultipartRequest.md)
 - [OperationRequest](docs/OperationRequest.md)
 - [OperationResponse](docs/OperationResponse.md)
 - [OperationTargetResponse](docs/OperationTargetResponse.md)
 - [OrderedQueryField](docs/OrderedQueryField.md)
 - [ProcessorRequest](docs/ProcessorRequest.md)
 - [ProcessorResult](docs/ProcessorResult.md)
 - [Project](docs/Project.md)
 - [PropertyDefinition](docs/PropertyDefinition.md)
 - [QueryExecuteRequest](docs/QueryExecuteRequest.md)
 - [QueryParameter](docs/QueryParameter.md)
 - [QuerySource](docs/QuerySource.md)
 - [RuleContainer](docs/RuleContainer.md)
 - [RuleEventData](docs/RuleEventData.md)
 - [RuleType](docs/RuleType.md)
 - [SaveContentRequest](docs/SaveContentRequest.md)
 - [ScaffoldRequest](docs/ScaffoldRequest.md)
 - [ScaffoldResult](docs/ScaffoldResult.md)
 - [Schema](docs/Schema.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionDiscount](docs/SubscriptionDiscount.md)
 - [Template](docs/Template.md)
 - [UpdateArtifactRequest](docs/UpdateArtifactRequest.md)
 - [UpdateDataRequest](docs/UpdateDataRequest.md)
 - [UpdateRulesetResponse](docs/UpdateRulesetResponse.md)
 - [UploadResponse](docs/UploadResponse.md)
 - [User](docs/User.md)
 - [UserData](docs/UserData.md)
 - [UserQuery](docs/UserQuery.md)
 - [UserRegistration](docs/UserRegistration.md)


## Documentation For Authorization


## api

- **Type**: API key
- **API key parameter name**: X-Logicdrop-ApiKey
- **Location**: HTTP header


## jwt

- **Type**: Bearer authentication (JWT)


## oauth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **admin:read**: API permission
 - **admin:write**: API permission
 - **admin:delete**: API permission
 - **cache:read**: API permission
 - **cache:write**: API permission
 - **cache:delete**: API permission
 - **cache:manage**: API permission
 - **client:read**: API permission
 - **client:write**: API permission
 - **client:delete**: API permission
 - **compute:read**: API permission
 - **compute:write**: API permission
 - **compute:delete**: API permission
 - **compute:execute**: API permission
 - **compute:manage**: API permission
 - **content:read**: API permission
 - **content:write**: API permission
 - **content:delete**: API permission
 - **data:read**: API permission
 - **data:write**: API permission
 - **data:delete**: API permission
 - **data:execute**: API permission
 - **email:execute**: API permission
 - **package:read**: API permission
 - **package:write**: API permission
 - **package:delete**: API permission
 - **project:read**: API permission
 - **project:write**: API permission
 - **project:delete**: API permission
 - **schema:read**: API permission
 - **schema:write**: API permission
 - **schema:delete**: API permission
 - **template:read**: API permission
 - **template:write**: API permission
 - **template:delete**: API permission
 - **template:execute**: API permission


## Author

support@logicdrop.com


